---
title: "Aristotle 101: Substance in the Categories"
date: 2020-03-15T11:33:25Z
tags: ["aristotle","substance","categories","emergence","transcendence"]
topics: ["philosophy"]
image: img/school-of-athens.jpg
draft: false
---

The Categories is Aristotle’s first attempt to outline a theory of being, in addition to the work’s central focus, which is to provide an account of the ways in which we think about being, and beings. In total, there are ten categories of thought about being, but the core of his theory of being begins with the first category. This is what he called “substance”. This essay will summarise Aristotle’s conception of substance as he presents it in The Categories, briefly explain what distinguishes substance from the other categories, and offer some additional thoughts about the metaphysics of being, in relation to Aristotle’s mentor, Plato.

So, what is substance, in what does substance consist, and what sets it apart from the other categories? The first two questions can be answered together. Once we’re clear on that, we can move on to the last question. To answer the first two questions, we need to make a distinction. Our first step will be to substitute a synonym for the word substance: being. When Aristotle talks about substance in The Categories, he primarily means to ask what it means *to be*. From this substitution, it should be relatively easy to see the two senses in which he wants to use the word substance: First, the space in which things can be; i.e. the state of being, itself. Second, the individual beings that occupy the space of being itself. Aristotle begins his inquiry by looking at particular beings – a horse, for example. Of that being, he asks two questions: whether or not it *is*, and *what* it is. A traditional way to phrase this, is to say that substance is both the “that-ness” and the “what-ness” of a thing; in the case of our horse, that it exists, and that it is a horse, combine to constitute the substance of the horse.

### Primary and Secondary Substance

Aristotle calls the first sense of being the “primary” substance: particular beings, in themselves. Self-sufficient instances of discrete existence, that depend on nothing for their existence (other than the prime matter out of which it arose in combination with the form imposed upon it at generation, but we’re getting ahead of ourselves. The next installment will discuss this in more detail). So, Socrates is a substance, that pen in your hand is a substance, the sun is a substance, and Flea Biscuit the racehorse is a substance. They are all “primary” substances insofar as they are independent subjects, about which various things can be predicated, and of which they are never predicated of other things (e.g., that Flea Biscuit is your pen, or that Socrates is a Flea Biscuit). So much for the primary substance.

For Aristotle, the science of metaphysics is the science of giving things their right names. In practice, then, metaphysics (at least in part), is the process of moving things from a state of being, to a state of being named. A substance becomes a subject when it is assigned a noun, and the two ways that nouns can be assigned demarcates the boundary between primary and secondary substance. Socrates, Flea Biscuit, The Parthenon, that pen, item no. 36248 in your Amazon shopping cart, and you, are all proper nouns, and therefore primary substances. But what could we give as a name, that would identify the secondary substance of a being? What could be *said of* Socrates, that would be indicative of Socrates, but only in a general sense, and not particular to his being? That name would move us from the “that-ness” of Socrates, to the “what-ness” of Socrates. We want to know not only *that* Socrates is, but also *what* he is. We can answer this question by saying of Socrates, that he *is a man*. In other words, we can predicate a universal of him. He belongs to a class of similar beings, called *mankind*. That class is the secondary substance.

### Species and Genus

Aristotle further divides secondary substance into two kinds: species and genus. Before continuing, a quick note of caution is in order. Though he was an avid naturalist and proto-biologist, Aristotle does not use these terms in the Linnean or genetic sense, as we do today. Rather, Aristotle is dealing with categories of thought. Things group together on account of the similar things that can be said of them. So, Socrates, Pericles, Speussipus, and Oedipus, are all particular subjects, but also members of the species *man*, because we would all say of them that they are two-footed, featherless, rational animals. But we’d also say that the pen in your hand is both a subject, and a species. It is a subject because it is an individual being; and it is a species, because it possesses attributes that are indicative of a class of beings: writing utensils. But, the pen in your hand is not *the* writing tool. It is one among millions of individuals, of which we can say similar things, of all of them: cylindrical, tipped with a liquid that sticks well to paper, fits comfortably in the hand. In other words, it is a member of the species of writing tools.

Aristotle recognized that it was possible to say of a being more than one thing. In the case of our pen, that it is a writing tool, and that it is an artefact. In the case of Socrates, that he is a man, and that he is an animal (as opposed to an artefact). This higher order attribution is what Aristotle calls the genus of a being. This way of saying something of a subject is still a kind of secondary substance predication, because we are still dealing with a universal classification. It is a more general concept, however, because it includes both individuals and species. Again, Aristotle is working with categories of thought, not genetic lineage, however it is true that the relation between genus, species, and individuals is hierarchical in nature. A species can never be an individual, in the same sense that Socrates is *a man*. Likewise, Socrates cannot *be man* as such, he can only be *a* man. And, obviously, the genus animal cannot be either the species man or the individual Socrates, though it does contain them both.

### Properties – Or, The Other Categories

How is it that we come to say of Socrates that he is Socrates, or that he is *a man*, as opposed to a seashell, or a pen? What is it that makes a pen a writing tool or an artefact? These questions signal the dividing line between substance and the rest of the categories. It is not my intention here, to catalogue all of the remaining nine categories. That will have to wait for another time. Suffice to say that, for Aristotle, it is the nature of a thing that determines the “what-ness” of a thing. And, the nature of a thing is determined by what can be *found in* that thing. For example, that Socrates was short, or had Socrates’ snub-nose, or spent his days in the Agora in Athens, or had Socrates’ white beard, or suffered Socrates’ daemon-haunted conscience, are all things that are particular attributes of Socrates, mark him out as Socrates, and are only *found in* Socrates. If he did not exist, then neither would his snub-nose, his white beard, nor his daemon-haunted conscience. The individual attributes, in other words, are entirely dependent upon the substance within which they are found.

As dependent particulars, the properties of Socrates would only exist while Socrates existed, but we should be careful to make one further distinction. Socrates’ particular snub-nose is *not* snub-noseness. Socrates does not have snub-noseness, he has a snub-nose. The white in Socrates’ beard is particular to Socrates, but also an instance of the universal property of whiteness, since it is present in the substance to which it is being predicated. This notion of universal property, is the closest analogy in Aristotle’s theory, to Plato’s famous Forms. But, unlike his mentor Plato, Aristotle insists that the universal of a property would not exist without at least one particular instance of its expression present in a being. If no individuals were expressing the color white in their beards, there could be no such thing as whiteness, and no such property could be (or reasonably would be) predicated of any subject. To make this point clear, try to imagine the fanciful property “schlerbness”. What would a thing that has “schlerb” look like? How would it behave? To what species of substance could we assign “schlerb” as a property? If one thing did exist that expressed the characteristic of schlerbness, these questions would all be easily answerable. Thus, all of the categories after substance rely in some sense on substance for their own existence, but substance itself stands alone as something that is *in nothing* (though, in the case of secondary substance, may be *said of* primary substance).

One last point of clarity is needed here, before we continue. Secondary substances are thought to be universals in some sense, as are universal properties. Are secondary substances dependent upon primary substances for their existence in the same way that the properties are? This can’t be the case, since even secondary substances are independent of their individuals. The species *man* need not rely on any surviving individual man, for it to exist. We would simply pass into speaking of mankind in the past tense. Likewise, the species unicorn has independent existence, whether or not any particular unicorn exists (or is being imagined). To speak of one, is to speak of *something*, albeit imaginary. Whereas, to speak of the pink in the unicorn’s mane, or the hardness of its horn, is to speak of properties that would be extinguished as soon as our imaginations moved on to something else more entertaining.

### Extended Discussion

From this outline, we can conclude that Aristotle was what we moderns would now call a “nominalist”, relative to his old master Plato. What this means, in a nutshell, is that Aristotle believed that the existence of abstract objects like universals (for the most part) is reliant upon the particular individuals that expressed the property being generalized. Plato, on the other hand, believed that a realm of eternal perfection was home to ideal “Forms” of not only all the qualitative and quantitative properties, but of all individuals as well. Everything in the world, according to Plato, is a sort of forger’s copy of these perfections (or, perhaps, that all particulars were participatory expressions of that singular form of perfection). This put Aristotle at direct loggerheads with his old teacher. For him, everything begins with the particular; both the particular individual and the particular property. These particular entities exhibit consistent patterns that we are able to recognize as rational animals, and it is these patterns that constitute our universal concepts as a product of reason. You might say that Plato was a top-down ontologist, while Aristotle was a bottom-up ontologist. This is the basis for the famous depiction of the two masters in Raphael’s famous School of Athens – Plato, points to the sky, while Aristotle gestures to the ground.

Aristotle’s bottom-up approach is admittedly a powerful tool for understanding the world around us. In particular, our subjective experience of that world, and how we are to make sense of it. It is Aristotle’s nominalism that was the inspiration for scientific inquiry for the next three thousand years, and the basic assumptions of that nominalism still permeate today’s modern science — especially the assumption that the world is patterned and predictable, and that these patterns are discernible by a rational process of observation and interpretation. But it is precisely this assumption that remains a problem for Aristotle, and his nominalist approach to metaphysics. The first question of the philosopher is not *how*, or even *what*, but *why*. Aristotle never thought to ask why this basic assumption always seems hold. He sought only to provide an account of the things that exist, from that assumption. This more fundamental question was what Plato was targeting. He eschewed the examination of horses and shellfish, not because he thought there was nothing to learn from that examination, but because that knowledge was only derivative of what the philosopher ought to be paying attention to. Studying individuals may give you a vast knowledge of the varieties of the Forms, but it won’t tell you why that knowledge is possible or even whether the Forms are the right theory for why everything isn’t just — as William James put it — a “blooming, buzzing confusion”.

### Conclusion

In any case, we’ve drifted far afield from were we began. So, it’s time to put a bow on this episode. The goal here was to show what Aristotle meant by substance in the Categories, and to outline why it is distinct from, and fundamental to, all the other categories, whatever those may be. In the next instalment, we will visit the topic of substances once again, only this time, from the version provided by Aristotle in the Metaphysics. I’ve sprinkled in a few concepts from that in this essay. So, this next instalment should help to clarify those insertions. Then, after we’re thoroughly confused, we’ll take a look at Michael Wedin’s book, “Aristotle’s Theory of Substance”, to get a look at how we might stitch the two versions of substance back together into a coherent whole.

```[Imported from exitingthecave.com on 29 November 2021]```

