---
title: "Book Review: Enlightenment Philosophy in a Nutshell"
date: 2019-07-28T12:27:36Z
tags: ["reviews", "enlightenment", "academia"]
topics: ["philosophy","history"]
image: img/enlightenment-nutshell.jpg
draft: false
---

*What’s the Goal?*

In the introduction to [*Enlightenment Philosophy In A Nutshell*](https://amzn.to/30Vzdsu), Jane O’Grady makes her intentions for the book quite explicit:

> *I hope to show how Descartes, Locke, Spinoza, Berkeley, Hume, Rousseau, and Kant respond to, develop, reform, and contradict the ideas of their predecessors and peers, such as Hobbes, Leibniz, Hutcheson, Voltaire, and Diderot, and in doing so, to convey the extraordinary courage and innovativeness of the Enlightenment as a whole*… (Pg. 9)

The problem with stating an ambitious goal like this so explicitly, is that a cautious reader will notice when the goal is not quite satisfied. The book does not (and, practically, cannot) include fair treatments of Hobbes, Leibniz, Voltaire, or Diderot. So it is difficult to show how the others are responding to to them, except by implication or characterization, which O’Grady does quite frequently.

She occasionally includes references to and passages from twentieth century philosophers as well, all of whom are responding to Descartes, Lock, Hume, and Kant. This is one of the better, and more subtle features of the book, because it vividly demonstrates the extent to which Enlightenment thinking still motivates, informs, and permeates philosophical discussions today. It further demonstrates that the conversation with Enlightenment thinkers is far from over, whether we’d like to think so, or not. But this still seems to me, to be a diversion from the very particular goal stated in the quote above.

Still, as a summary handbook of the ideas and arguments of the most essential thinkers of the Enlightenment, no student could go wrong in purchasing this volume. The chapters on Locke, Spinoza, and Kant, easily make this book well worth the jacket price. What’s more, the introduction and chapter one are so pregnant with interesting talking points, that I’ve decided to make the bulk of this review a direct response to those two chapters alone, after a brief comment on the problem of ‘compression’.

### The Problem of Compression

Early in the introduction, O’Grady laments:

> …*how can [the history and ideas of the Enlightenment] be crammed into a nutshell? It can’t, of course, but compression is sometimes a handy tool for communicating the sense of a subject and inspiring further investigation*… (Pg. 9)

The question is, *what “sense”*? O’Grady would probably object that my criticism thus far is unfair, given the scope and nature of her project. Grayling’s recent tome, *The Age of Genius*, which spanned the intricacies of the 30-years-war for most of the first half of the book, still managed to over-simplify the motivations of many of the characters involved, despite being 370 pages in length. So, how is it reasonable to expect a summary work such as this one to be any more nuanced? O’Grady might have a point, if my complaint were simply that she over-simplifies the history. Rather, what I am complaining about here, is that the book uses “compression” as a cover for retelling the same storybook narrative that has been repeated about the Enlightenment, *ad nauseam*: evil repressive monolithic church, versus freethinking swashbucklers who triumph over this evil for progress, in the end. Roll credits. Play anthem.

But subsequent history has made it clear that the value of religion, and the reliance on tradition, are both far more significant than the nineteenth century progressive interpretation of Enlightenment “liberation” would permit. What’s more, its clear from subsequent biographical and historical scholarship, that for most Enlightenment thinkers (Hume excluded, perhaps), a relationship with the western God and adherence to his church, was not simply a cynical or cowardly ploy to avoid personal harm. This is not to assert that Enlightenment thinkers did not face threats, at times, for their dissidence. Of course, they did. Rather, I am suggesting that we should take their belief seriously, unless we have some indubitable ground for questioning it. Summary treatments of a spectacularly large subject like the Enlightenment lend themselves to just this sort of bias. So, that “sense of the subject” which O’Grady wants to convey, just ends up being the sense that flatters the preconceptions of the Oxbridge set, and the common English view of intellectual history.

This is not to suggest that there isn’t at least some truth in that perspective. But the broader question then becomes, “who is this book for?”. O’Grady says she wants this compression to “inspire further investigation”. The way this book is structured, I do think it would function as an excellent guide for group discussions of the major events and ideas of the Enlightenment. So, perhaps a classroom or a meetup group of philosophy enthusiasts would find this book valuable. The book reads as if we’re in a private dialogue with Jane herself, and this informal conversational style makes the book a pleasure to read, and much less onerous than heavier tomes like Gottlieb’s “Dream of Enlightenment”. So, perhaps the risk of distortion is worth the possibility of opening up the Enlightenment to a new generation of seekers, willing to explore its deeper meanings. In what follows, I offer two such interpretations.

### Enlightenment as Rescue

As with many modern Anglo-American philosophers, O’Grady is susceptible to the nineteenth century view of the Enlightenment as an antidote to medieval Catholic scholasticism, and a much needed reaction to the ostensible hegemony of the Catholic church. She quotes Kant’s “*What Is Enlightenment*” approvingly, to this effect:

> *…’Enlightenment is man’s emergence from his self-imposed immaturity’, is the first sentence of Kant’s essay on Enlightenment – ‘self-imposed’ because of what Kant considers our ‘laziness and cowardice’ in failing to think for ourselves without being guided by others. ‘If I have a book to understand for me, a pastor to serve as my conscience, a doctor to decide my diet, and so on, I need not exert myself at all. I need not think, if I can only pay’…* (Pg. 15)

When one considers the implications of these assertions from Kant, it is difficult to take him seriously. For starters, his condemnation of all who’ve gone before, as lazy and cowardly, is as cynical as it is itself lazy. Enlightenment thinkers were constantly cribbing material from the church fathers, even as they claimed a “starting from scratch” project. Second, I am struggling to think of a time when I’ve had thoughts of my own that weren’t guided in some way by all these thinkers from the Enlightenment — either by adaptation or reaction. Lastly, if the immaturity was self-imposed, and its source was a natural laziness and/or cowardice, it is difficult to imagine why we would ever want to bother being awakened from any ‘dogmatic slumber’.

Kant was shaping the lens through which several later generations would view the Enlightenment, the medieval thinkers that preceded it, and most importantly, themselves relative to it all. It seems to me the modern Anglo-Americans are also wearing Kant’s glasses. Take, for example, O’Grady’s characterization of Kant’s remarks, from the same page:

> *…Enlightenment thinkers were trying to do what the ancient Greeks had done: think from first principles, and persuade everyone else to do so, too. They urged criticism of all beliefs and ideas, including their own, and the promulgation of new ones…* (Pg. 15)

The implication here, clearly borrowed from Kant, is that no such effort was taking place anywhere else in the church-dominated culture of the West, prior to the Enlightenment. Kant certainly believed this. But (to borrow the Royal Society’s motto for a moment) why should we take his word for it? Of course, there’s nowhere near enough space or time in the book for O’Grady to address this question. So, I am left to pursue that question myself. Later, O’Grady claims that the Encyclopedia of Diderot and d’Alembert was suppressed by the church, but doesn’t actually explain the politics of that suppression, instead juxtaposing it with Galileo’s recantation and subsequent house arrest, as if the two were related, or that Diderot and d’Alembert faced the same sort of threat. She likewise equates Descartes’ self-suppression of his “*Treatise of the World*” with this threat, but offers no explanation for why he later felt entirely comfortable submitting his Meditations to the scholastics in Paris, under his own name.

The picture painted for the reader is clear enough, and it is a common trope in retellings of the Enlightenment: the monolithic church was a ubiquitously oppressive force, and the thinkers of the Enlightenment were brave revolutionaries and visionaries who only paid cynical lip-service to this backward religion, in order to avoid the fate of Giordano Bruno. Indeed, O’Grady’s consonance with Kant’s view of pre-Enlightenment society, and the significance of the Enlightenment as a movement, is explicit:

> …*Enlightenment thinkers unanimously saw themselves as throwing off the shackles of religious and state authority*… (Pg. 15)

But, is this actually the case? Why, for instance, would Descartes submit both his Discourse and his Meditations, to the authority of the Sorbonne, then? Why would he have cared what their opinion was? Why would Locke have spent so much effort tutoring nobles and princes? Why, for that matter, would Kant have bothered seeking a position as a university lecturer? Perhaps the issue they had wasn’t with authority *per se*, but with authority as constituted? It’s hard to say, and the book never explores this nuance.

O’Grady, sensing that some nuance is warranted in this characterization, does say this in her own defense:

> *…Even revisionists who insist that the ‘Dark Ages’ had their own sort of light would admit that great thinkers such as Augustine, Abelard, and Aquinas had been constrained by the need to examine religious questions and not exceed prescribed Christian boundaries…* (Pg. 16)

But this just isn’t the case. Enormous intellectual, ecumenical, and theological battles were raging throughout the church across the whole of the so-called ‘Dark Ages’. Augustine and Plotinus represented one major sect in a theological war with Aquinas and Abelard, over the Platonic versus the Aristotelian conception of not just the nature of the soul, the location of heaven, and the meaning of the crucifixion, but *also*, the nature and behavior of the planets, the nature of the earth and the creatures within it, the correct methods of reasoning, and much more. The end result of that battle, by the fifteenth century, had left the Augustinians far outside the authoritative canon of Catholic theology, and yet that scholarly tradition persisted within the church despite losing its ascendancy. How is this possible in a world where a pre-existing totalizing dogma is already the rule? In fact, the world of the medievals is far more complicated than we moderns care to grant it, and the relationship of the Enlightenment thinkers to that history is far more confused and misunderstood than this just-so story is willing to reveal.

### Enlightenment As Cautionary Tale

In spite of her pronounced modern Anglo-American perspective, O’Grady is not naive about the Enlightenment. She recognizes some of the inherent problems of Enlightenment thinking, and does the reader a great service in pointing these out from time to time, and demonstrating the importance of these flaws in the modern debate. For example, on the principle of universalism, which is core to Enlightenment humanism, she points out:

> …*it was precisely exploitation, eurocentrism, and racism that the Enlightenment was attacking… for the diversity of cultures to be celebrated, it was first necessary that they were not belittled or vilified — that the assumed exclusivity and superiority that European, and other cultures, assumed to themselves be transcended and respect be extended to all. Enlightenment universalism was what enabled the very identity politics that now condemns it. It is a victim of its own success and of the incessant critiquing that was so essential to it*… (P. 19)

One can hear whispers of Nietzsche in this. His identification of the Will To Truth, that corroded Western religion, it seems has also corroded Western culture itself. But O’Grady’s insight is even more subtle than this, and more relevant to the present. She is hinting at a strange role-reversal that seems to have overtaken contemporary politics, as a consequence of centuries of struggling with the ideal of universalism:

> *…Enlightenment thinkers saw themselves as ‘citizens of the world’, yet oddly, many on the present-day [radical] left would probably agree with the reactionary aristocrat Joseph de Maistre, who objected that the Republican constitution of 1795 ‘has been drawn up for Man’, and that ‘a constitution that has been drawn up for all nations is made for none.’ For de Maistre averred that, although in the course of his life he had come across Frenchmen, Italians, Russians, and even (thanks to Montesquieu’s Persian Letters) Persians, he had never met ‘Man’…* (Pg. 23)

While the radical left today is dedicated to borderless globalism, it is still true that those in the identity politics movement insist that the notion of a universal “Man” is just a narcissistic projection of “white supremacy” (or, at least, colonialist chauvinism) on all the world. And O’Grady further correctly points out that:

> …supporters of identity politics similarly deny that there can be any general ‘human’ interests, any more than there can be ‘truth’… (Pg. 23)

Still, there is something O’Grady has missed, perhaps because her vantage point does not make it easy to see. There are identitarians *on both the left and the right*, and they both would deny the reality of the universal ‘Man’. For the left, this denial amounts to a condemnation of the Enlightenment as a fundamentally racist project. For the right, however, this denial is an affirmation of an obvious fact (at least, to them): the domination of western culture (and the white men that populate it) in the form of the products of the Enlightenment, makes explicit what Enlightenment thinkers took as an unacknowledged self-evident truth: Western culture is superior, and promotion of Enlightenment ideas helps to preserve that superiority — i.e., that there indeed just are the interests of specific peoples, and that we who belong to this group of peoples have a duty to defend and promote those interests, everywhere in the world.

Both interpretations of the idea of Enlightenment universalism are pernicious and cynical corruptions. The thinkers of the Enlightenment were neither unconscious of the true nature of their project, nor were they disingenuous about it. They may have been mistaken, but they *really did* subscribe to the notion of the universal brotherhood of man, and to the notion of the equal human dignity this afforded all men. They *really did* see themselves as ‘citizens of the world’, and were not simply adopting, in Foucaultian terms, language effective for the accumulation of power to themselves (whether for good or bad purposes). To take the cynical view of universalism, is to make the same mistake as with their religious beliefs: to read backward into history a secret psychological motive that helps to confirm a flattering view of ourselves, relative to them.

O’Grady rightly recognizes this problem, and highlights one of the sources of this distortion in the way that we interpret Kant today:

> …*There is something anachronistic in the way **sapere aude** (Kant’s declared motto of Enlightenment) is so often translated as ‘dare to think for yourself’, when its more accurate translation is ‘dare to know’… thinking for yourself was important, not for its own sake, but rather… [they] expected that subjective reasonings would ultimately converge on objective truth… the exhortation to free thinking has been exaggerated and distorted into the notion that all opinions are important and equally valid… [thus ironically encouraging] the return of group-think within cultural boundaries…* (Pg. 23)

The twenty-first century argument clearly seems to be taking us back to the Nietzschean struggle between the Will To Power and the Will To Truth, and O’Grady points to this in her book, even if only by suggestion. Her awareness of the significance of the Enlightenment does not stop there. O’Grady also outlines a further Nietzschean warning about the Enlightenment:

> …The backlash against reason which led to Romanticism was in fact part of the Enlightenment itself. In the very act of dethroning superstition and authority, and crowning human dignity and freedom of thought, reason began the discovery of how insignificant and irrational human beings really are. Elevating humans and human reason led to the downgrade of both… The fabulous fecundity of the Enlightenment was the gateway to modern bleakness — to Freud, who would see reason as a specious gloss over our wild unconscious desires, and to Darwin, who would show us to be glorified apes. It was the beginning of what Weber called ‘the disenchantment of the world’ in which divinity would be stripped away, not just from the cosmos, but from ourselves… (Pg. 25)

Yet, while acknowledging the bleakness of a world bereft of divinity, she seems to think that the liberation from ‘superstition’ was worth the price we’ve paid. Was it? I have been an atheist and a seeker for most of my life. Until very recently, I would have said yes. I no longer think this. I will reserve an explanation for this change for another post, but the point I wish to make here, is that this “disenchantment” is perhaps the most significant and devastating feature of the Enlightenment, and that the Enlightenment thinkers who emphasized human dignity and political individualism were unconsciously reacting to the implications of this disenchantment in the only way they knew how: by trying to reinvent it anew, as a ‘natural’ phenomenon. O’Grady doesn’t spend a lot of time on this, but readers of this book will want to explore the writings of modern thinkers who do.

### Conclusion

This book does far more than “inspire further investigation”. It is a compact hand-grenade with the explosive power of an H-bomb. Anyone with the ambition and the sensitivity to the philosophical conundrums addressed in this book, could find himself on a life-long quest hunting down the splinters in the mind it leaves behind. This is why I was disappointed not to find a decent bibliography in the back of the book. Only the most ambitious (and most adroit at the internet search) is going to have any luck tracking down many of the casual references O’Grady litters throughout this text. From Aquinas’ Summa Contra Gentiles, to Adorno’s Dialectic of Enlightenment, to Simon Blackburn’s Quasi-Realism, if the reader doesn’t already know what he’s looking for, he’s likely to be frustrated by this book, absent a bibliography. Indeed, if he doesn’t already know what he’s looking for, there’s a good chance he might miss some of these, because they’re often offered as vague “other philosophers think” asides.

But, given a wise guide, and a group with which to discuss the men and ideas presented in this book, I think the book is a fantastic place to begin the journey, not just in the ideas of the Enlightenment, but in philosophy itself. One of the great advantages of starting a philosophical journey from the Enlightenment outward, is that it fills the seeker with very much the same sort of enthusiasm that the Enlightenment thinkers themselves were filled. *Enlightenment Philosophy In A Nutshell* is itself brimming with precisely this same sort of enthusiasm, and despite the aforementioned annoyance, would thus make an excellent handbook for those new to the journey of philosophy.

```[Imported from exitingthecave.com on 29 November 2021]```

