---
title: "The Ought in the Machine"
date: 2017-01-02T17:35:43Z
tags: ["moral psychology","truth","realism","veneer theory"]
topics: ["philosophy","psychology"]
image: img/choice-sign.jpg
draft: false
---

> *“If I must choose between peace and righteousness, I choose righteousness”* ~Theodore Roosevelt

I have long held the belief that moral self-justification is both the engine and the doom of the world. Nobody does what they do thinking to themselves “this is the wrong thing, so I should do it”, or desiring to do wrong for its own sake. Even people as evil as Hitler, Stalin, and Pol Pot all had reasons for why they did what they did. Reasons that they believed made them right to do what they did. Some even wrote whole books justifying themselves.

Today, we have strong scientific evidence to explain and describe various specific phenomena like [Noble Cause Corruption](https://en.wikipedia.org/wiki/Noble_cause_corruption), [Cognitive Blindness](http://psychology.wikia.com/wiki/Inattentional_blindness), and [Motivated Reasoning](https://www.psychologytoday.com/basics/motivated-reasoning). But what we don’t yet have (as far as I am aware), is a biological explanation for the existence of the impulse that leads to these things – in other words, the *impulse to morally self-justify*. What could possibly be the evolutionary / reproductive advantage of self-justification? The Stanford Encyclopedia of Philosophy [puts it this way](https://plato.stanford.edu/entries/morality-biology/):

> *When it comes to morality, the most basic issue concerns our capacity for normative guidance: our ability to be motivated by norms of behavior and feeling through judgments about how people ought to act and respond in various circumstances (Joyce 2006, Kitcher 2006a,b, 2011, and Machery and Mallon 2010). Is this human capacity a biological adaptation, having perhaps conferred a selective advantage on our homini[d] ancestors by enhancing social cohesion and cooperation? …If so, then it would be part of evolved human nature to employ moral judgment in governing human behavior, rather than a mere “cultural veneer” artificially imposed on an amoral human nature (de Waal 2006).*

The fact that this question remains fundamentally unanswered can be intuited by the fact that numerous quasi-scientific specializations have popped up in the past two decades inspired by it. Evolutionary Psychology, and Moral Psychology, the two most prominent. As hinted at in the SEP in the citation from Frans de Waal, there are some who think morality as a whole, including phenomena like self-justification, is nothing but a culturally constructed illusion (incidentally, it is an interesting and disturbing repeating theme in philosophy and science these days, to condemn common experiences as “illusions”. Why is that?). Others argue that the biological facts are themselves enough to deflate the importance of morality to nothing more than an incidentally adaptive feature, like gills or lungs:

> *Darwin’s sometimes diffuse speculations about the “social instincts” have given way to theories firmly grounded in logic and fact, the theories of reciprocal altruism and kin selection. And they don’t leave our moral sentiments feeling as celestial as they used to. Sympathy, empathy, compassion, conscience, guilt, remorse, even the very sense of justice, the sense that doers of good deserve reward and doers of bad deserve punishment— all these can now be viewed as vestiges of organic history on a particular planet. (Wright 2010)*

And yet, there it is, all the same. It is this impulse, illusory or not, that drove Homer to write his epics, that drove Plato to toss all of his tragedies into a fire and embark instead down the path of the dialectic as Socrates’ life-long student, that drove Diogenes to the brink of madness, wandering the streets of Athens with a lamp (if the apocryphal stories are to be believed). Over the centuries, this impulse has given fuel not only to philosophers, but to kings and generals, despots and tyrants, radicals and revolutionaries, fathers and sons, mothers and daughters. It ended the life of Julius Caesar, converted the Roman empire to Christianity, divorced Europe and England from the medieval church of Rome, separated the North American colonies from the British empire, ended the slave trade, turned Europe and the Middle East into a killing field for nearly all of the 20th century, and now sends fanatics hurtling into buildings and crowds loaded with explosives and guns, continues to fuel a never-ending western campaign in the middle east, and is slowly turning university campuses back into self-denying and self-deluding monasteries. And, so far, the future looks to be just as replete with examples like this.

For all the talk of it’s illusory, or teleologically meaningless biological nature, moral self-justification is perhaps the single most defining feature of the human species. And yet, we know so little about it. For all the theories explaining various features of morality that Wright and de Waal expound upon on their books, the body of knowledge is really very thin, compared with even basic physiology or even psychology. And there doesn’t actually seem to be much urgency about it. As Wright himself admits:

> *The religious sense has indeed waned, especially among the intelligentsia… among ethical philosophers, there is nothing approaching agreement on where we might turn for basic moral values— except, perhaps, nowhere. It is only a slight exaggeration to say that the prevailing moral philosophy within many philosophy departments is nihilism.*

I have deeply mixed emotions about this. On the one hand, the authors of these books all seem to paint a picture in which armies of intellectually curious Dr. Mengeles, unmoored from empathy or compassion, roam the planet torturing each other out of nothing more than a desire to experiment. It’s a compelling story: what sort of monsters would we be, without these moral “guard rails” to keep us on the straight-and-narrow?

But Josef Mengele *had* a moral compass. One aligned with his master, Adolf Hitler. What sort of life would Mengele have chosen for himself instead, if his moral fervor had been dampened severely by a capacity to reason disinterestedly about what was taking place around him in the 1930’s? But, that’s the rub. Human beings **can’t** reason purely disinterestedly about their circumstances. They are *emotional* creatures — *moral* animals, as Wright calls them. Mengele did what he did, not because he was *amoral*, but because he was *immoral*. But we’ve lost the will to admit this anymore.

This is why philosophy is so, so important today — and what frustrates me enormously about most of what I see coming out of philosophic production centers today. For all the sophistication and depth that we’ve gained from our scientific understanding of morality and its origins, science cannot tell us what to do with this impulse to “be good”, in a world where fundamental survival and subsistence is no longer a central concern. Reciprocal altruism and kin selection, in their crudest forms, work for the apes. Frans de Waal has done amazing work showing this, and showing how they constitute the fundamental building blocks of our own moral feelings. But human civilization is far more complex, and several orders of sophistication removed from the tribal warfare of chimpanzee troupes in the jungle. I want to know how I should manage my desire for reciprocity in my relationships. What sort of importance ought I put on my kin and community? What is the appropriate amount of sympathy, remorse, gratitude, or compassion for a given situation I may be in? What meaning can I give to terms like “justice” and “fairness”? What are the implications built-in to the answers to all these questions?

But, as Wright seems to have correctly pointed out, academic philosophy has all but abandoned any desire to systematize any understanding of these questions. Instead, the topic has more or less fractured into secondary vocational concerns, such as “human rights”, or “medical ethics” or “business ethics”, which are really just jurisprudence specializations borne out of the direct needs of government and industry. In the vacuum, we can see all around us what has been slowly taking it’s place. Moral crusaders are everywhere in academia – from the [physical sciences](http://discovermagazine.com/2011/mar/14-priest-physicist-would-marry-science-religion), to [psychology](http://thefederalist.com/2016/10/17/canadian-professor-ignites-protests-refusing-use-transgender-pronouns/), to [social studies](http://theothermccain.com/2016/11/23/womens-studies-professor-accuses-trump-supporters-of-terrorism/), and [law](http://uk.businessinsider.com/alan-dershowitz-hits-back-at-student-protesters-2015-11?r=US&IR=T). These crusaders are followed closely behind by academicians in other fields — [some](http://righteousmind.com/) [more credible](http://physics.wm.edu/~remler/PPP.html) [than](http://www.michaelshermer.com/the-moral-arc/) [others](https://www.samharris.org/books/the-moral-landscape) — essentially doing the work of philosophy for the philosophers.

Why is this happening? Why has academic philosophy taken this route? Where are the philosophers? In an era when academic philosophy is most needed, and an era when accusations of [irrelevance](http://mysteriousuniverse.org/2014/05/when-philosophy-is-irrelevant/), [uselessness](http://www.philosophersmag.com/index.php/footnotes-to-plato/61-on-the-uselessness-of-much-academic-philosophy), [corruption](https://www.theguardian.com/books/2010/feb/27/beyond-hoax-alan-sokal), (and even “[death](https://philosophynow.org/issues/82/Hawking_contra_Philosophy)”) are coming from almost every quarter, and an era where religion is no longer seen as the answer to morality that it once was by large segments of the population, it boggles my mind why modern academic philosophy has not taken up this charge with full force — a charge it is both best suited, and arguably duty-bound, to assume.

Perhaps the reason is that philosophers fear a recurrence of what happened in the wake of the rise of German philosophy in the late 1890’s? Perhaps the prospect of a failure that large happening again is too much to face? Or perhaps, that failure had already destroyed philosophy as a systematic discipline, and we’re only just now — after 60 years of recovery from the globe-spanning wars it enabled — coming to that realization? I’d like to believe that’s not the case. At a time when we’re on the brink of yet another round of globe-spanning terrors, I would like to think that the philosophers are hard at work trying to fix the problems and find the answers that they couldn’t seem to find, in 1939.

At the center of that struggle, in my view, lies morality. Our moral consciousness is at the epicenter of our sense of free will, the core of our emotional experiences, the bedrock of our individual identities, the binding chords of our relationships and social structures, and the frameworks of our political systems. Moral *psychology* is not enough. *Evolutionary* morality is not enough. What we need is *moral philosophy*, now more than ever.

------

*Waal, Frans de; Stephen Macedo; Josiah Ober (2009). Primates and Philosophers: How Morality Evolved (Kindle Location 94) Princeton Science Library. Princeton University Press. Kindle Edition.*

*Wright, Robert (2010). The Moral Animal: Why We Are, the Way We Are: The New Science of Evolutionary Psychology (Kindle Locations 5672-5682). Knopf Doubleday Publishing Group. Kindle Edition.*

```[Imported from exitingthecave.com on 1 December 2021]```

